use leptos::*;
use leptos_router::*;

#[component]
pub fn AddSeries() -> impl IntoView {
    let add_series = expect_context::<Action<AddSeries, Result<(), ServerFnError>>>();
    view! {
        <div class="card p-3">
            <div class="card-heading">
                <h2>Add Series</h2>
            </div>
            <div class="card-body">
                <ActionForm action=add_series>
                    <div class="input-group mb-3">
                        <input type="text"
                            name="name"
                            class="form-control"
                        />
                    </div>
                    <div>
                        <input type="submit"
                            class="btn btn-primary"
                            value="Add Series"
                        />
                    </div>
                </ActionForm>
            </div>
        </div>
    }
}

#[server(AddSeries)]
pub async fn add_series(name: String) -> Result<(), ServerFnError> {
    use crate::db::load_statement;
    use sqlx::{Pool, Postgres};
    let pool = expect_context::<Pool<Postgres>>();

    let s = load_statement("insert_series.sql");
    sqlx::query(&s)
        .persistent(true)
        .bind(name)
        .execute(&pool)
        .await?;

    leptos_axum::redirect("/");

    Ok(())
}
